/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "PerforceActionWhere.h"
#import "PerforceOutputParsers.h"
#import "AppUtils.h"

#import "AppDefaults.h"

@implementation PerforceActionWhere

+ (void) defaultRunFor:(id)owner
		 selector:(SEL)aSelector
		 withPath:(NSString*)depotPath
{
	PerforceActionWhere* action = [[[PerforceActionWhere alloc] init] autorelease];
	
	[action runFor:owner selector:aSelector withPath:depotPath];
}
		 
- (void) dealloc
{
	[fOwner release];
	[fFilePath release];
	[fDepotPath release];
	
	[super dealloc];
}

- (void) runFor:(id)owner 
         selector:(SEL)aSelector 
		 withPath:(NSString*)dirPath
{
    NSMutableArray* commandAndArgs = [[[NSMutableArray alloc] init] autorelease];
	
	fOwner			= [owner retain];
	fSelector		= aSelector;
	
	[commandAndArgs addObject:@"where"];
	
	[commandAndArgs addObject:dirPath];
    
	[self runAction:commandAndArgs stdInString:nil readToEOF:YES];
}

static NSString* kSpaceToken = @" ";
static NSString* kEOLToken   = @"\n";

- (void) processOutput: (NSString*) perforceOutput
{
	NSScanner* scanner = [NSScanner scannerWithString:perforceOutput];
	
	// Get depot path, skip client path, get local path
	[scanner scanUpToString:kSpaceToken intoString:&fDepotPath];
	[scanner scanString:kSpaceToken intoString:nil];
	[scanner scanUpToString:kSpaceToken intoString:nil];
	[scanner scanString:kSpaceToken intoString:nil];
	[scanner scanUpToString:kEOLToken intoString:&fFilePath];

	[fFilePath retain];
	[fDepotPath retain];
}

- (void) processError: (NSString*) perforceError
{
	SendErrorMessage ("File or path not found\n");
}

- (NSString*) getFilePath
{
	return fFilePath;
}

- (NSString*) getDepotPath
{
	return fDepotPath;
}

@end
